@@ -2,7 +2,7 @@ module Main where
 import Control.DeepSeq
 import Control.Exception
 import Control.Monad
-import Criterion.Main
+import Criterion.Main hiding (defaultConfig)
 import Data.String
 import Database.Postgres.Temp.Internal
 import Database.Postgres.Temp.Internal.Config
@@ -17,7 +17,7 @@ defaultConfigDefaultInitDb :: Config
 defaultConfigDefaultInitDb = mempty
   { plan = mempty
     { logger = pure mempty
-    , postgresConfigFile = defaultPostgresConfig
+    , postgresConfigFile = fastPostgresConfig
     , initDbConfig = pure mempty
     }
   }
@@ -43,36 +43,35 @@ testQuery db = do
   bracket (PG.connectPostgreSQL theConnectionString) PG.close $
     \conn -> void $ PG.execute_ conn "INSERT INTO foo1 (id) VALUES (1)"
 
-setupCache :: IO (Bool, CompleteDirectoryType)
+setupCache :: IO CacheResources
 setupCache = do
   cacheInfo <- setupInitDbCache defaultCacheConfig
-  void (withConfig (silentConfig <> toCacheConfig cacheInfo) (const $ pure ()))
+  void (withConfig (defaultConfig <> cacheResourcesToConfig cacheInfo) (const $ pure ()))
   pure cacheInfo
 
 setupWithCache :: (Config -> Benchmark) -> Benchmark
-setupWithCache f = envWithCleanup setupCache cleanupInitDbCache $ f . (silentConfig <>) . toCacheConfig
+setupWithCache f = envWithCleanup setupCache cleanupInitDbCache $ f . (defaultConfig <>) . cacheResourcesToConfig
 
-setupCacheAndSP :: IO ((Bool, CompleteDirectoryType), CompleteDirectoryType, Once Config)
+setupCacheAndSP :: IO (CacheResources, Snapshot, Once Config)
 setupCacheAndSP = do
   cacheInfo <- setupCache
-  let cacheConfig = silentConfig <> toCacheConfig cacheInfo
+  let cacheConfig = defaultConfig <> cacheResourcesToConfig cacheInfo
   sp <- either throwIO pure <=< withConfig cacheConfig $ \db -> do
     migrateDb db
     either throwIO pure =<< takeSnapshot Temporary db
 
-  snapshotConfig <- (silentConfig <>)
-    <$> configFromSavePoint (toFilePath sp)
-  let theConfig = snapshotConfig <> cacheConfig
+  let theConfig = defaultConfig <> snapshotConfig sp <> cacheConfig
+
 
   pure (cacheInfo, sp, Once theConfig)
 
-cleanupCacheAndSP :: ((Bool, CompleteDirectoryType), CompleteDirectoryType, Once Config) -> IO ()
+cleanupCacheAndSP :: (CacheResources, Snapshot, Once Config) -> IO ()
 cleanupCacheAndSP (x, y, _) = cleanupSnapshot y >> cleanupInitDbCache x
 
 setupWithCacheAndSP :: (Config -> Benchmark) -> Benchmark
 setupWithCacheAndSP f = envWithCleanup setupCacheAndSP cleanupCacheAndSP $ \ ~(_, _, Once x) -> f x
 
-setupWithCacheAndSP' :: (CompleteDirectoryType -> Benchmark) -> Benchmark
+setupWithCacheAndSP' :: (Snapshot -> Benchmark) -> Benchmark
 setupWithCacheAndSP' f = envWithCleanup setupCacheAndSP cleanupCacheAndSP $ \ ~(_, x, _) -> f x
 
 main :: IO ()
@@ -82,12 +81,12 @@ main = defaultMain
   --    withConfig defaultConfigDefaultInitDb $ const $ pure ()
 {-
   bench "withConfig silent" $ whnfIO $
-    withConfig silentConfig $ const $ pure ()
+    withConfig defaultConfig $ const $ pure ()
 
   , setupWithCache $ \cacheConfig -> bench "withConfig silent cache" $ whnfIO $
       withConfig cacheConfig $ const $ pure ()
 
-  , bench "with migrate 10x" $ whnfIO $ replicateM 10 $ withConfig silentConfig $ \db ->
+  , bench "with migrate 10x" $ whnfIO $ replicateM 10 $ withConfig defaultConfig $ \db ->
       migrateDb db >> testQuery db
 
 -}
@@ -100,18 +99,18 @@ main = defaultMain
   , setupWithCache $ \cacheConfig -> bench "withSnapshot migrate 10x and cache" $ whnfIO $ withConfig cacheConfig $ \db -> do
       migrateDb db
       void $ withSnapshot Temporary db $ \snapshotDir -> do
-        snapshotConfig <- (silentConfig <>) <$> configFromSavePoint (toFilePath snapshotDir)
-        replicateM_ 10 $ withConfig snapshotConfig testQuery
+        let theSnapshotConfig = defaultConfig <> snapshotConfig snapshotDir
+        replicateM_ 10 $ withConfig theSnapshotConfig testQuery
 {-
   , setupWithCacheAndSP $ \theConfig -> bench "withConfig pre-setup with withSnapshot" $ whnfIO $
       void $ withConfig theConfig $ const $ pure ()
 
-  , setupWithCacheAndSP' $ \sp -> bench "configFromSavePoint" $ whnfIO $ void $ configFromSavePoint $ toFilePath sp
+  , setupWithCacheAndSP' $ \sp -> bench "snapshotConfig" $ whnfIO $ void $ snapshotConfig $ toFilePath sp
 
-  , bench "migrateDb" $ perRunEnvWithCleanup (either throwIO (pure . Once) =<< startConfig silentConfig) (stop . unOnce) $
+  , bench "migrateDb" $ perRunEnvWithCleanup (either throwIO (pure . Once) =<< startConfig defaultConfig) (stop . unOnce) $
       \ ~(Once db) -> migrateDb db
 -}
-  , bench "withSnapshot" $ perRunEnvWithCleanup (either throwIO (pure . Once) =<< startConfig silentConfig) (stop . unOnce) $
+  , bench "withSnapshot" $ perRunEnvWithCleanup (either throwIO (pure . Once) =<< startConfig defaultConfig) (stop . unOnce) $
       \ ~(Once db) -> void $ withSnapshot Temporary db $ const $ pure ()
 
   ]
