@@ -8,6 +8,7 @@ module Database.Postgres.Temp.Internal where
 import Database.Postgres.Temp.Internal.Core
 import Database.Postgres.Temp.Internal.Config
 
+import           Control.DeepSeq
 import           Control.Exception
 import           Control.Monad (void)
 import           Control.Monad.Trans.Cont
@@ -15,6 +16,7 @@ import           Data.ByteString (ByteString)
 import qualified Data.Map.Strict as Map
 import qualified Database.PostgreSQL.Simple as PG
 import qualified Database.PostgreSQL.Simple.Options as Client
+import           GHC.Generics
 import           System.Exit (ExitCode(..))
 import           System.IO.Unsafe (unsafePerformIO)
 import           System.Process
@@ -94,18 +96,31 @@ toTemporaryDirectory = resourcesTemporaryDir . dbResources
 -------------------------------------------------------------------------------
 -- Life Cycle Management
 -------------------------------------------------------------------------------
--- | Default postgres options
---
---   @since 1.12.0.0
-defaultPostgresConfig :: [String]
-defaultPostgresConfig =
+{-|
+The fastest config we can make.
+
+ @
+   shared_buffers = 12MB
+   fsync = off
+   synchronous_commit = off
+   full_page_writes = off
+   log_min_messages = PANIC
+   log_min_error_statement = PANIC
+   log_statement = none
+   client_min_messages = ERROR
+ @
+
+@since 1.21.0.0
+-}
+fastPostgresConfig :: [String]
+fastPostgresConfig =
   [ "shared_buffers = 12MB"
   , "fsync = off"
   , "synchronous_commit = off"
   , "full_page_writes = off"
-  , "log_min_duration_statement = 0"
-  , "log_connections = on"
-  , "log_disconnections = on"
+  , "log_min_messages = PANIC"
+  , "log_min_error_statement = PANIC"
+  , "log_statement = none"
   , "client_min_messages = ERROR"
   ]
 
@@ -122,9 +137,9 @@ The default configuration. This will create a database called \"postgres\"
    fsync = off
    synchronous_commit = off
    full_page_writes = off
-   log_min_duration_statement = 0
-   log_connections = on
-   log_disconnections = on
+   log_min_messages = PANIC
+   log_min_error_statement = PANIC
+   log_statement = none
    client_min_messages = ERROR
 @
 
@@ -138,7 +153,8 @@ Alternatively you can eschew 'defaultConfig' altogether, however
 your @postgres@ might start and run faster if you use
 'defaultConfig'.
 
-The 'defaultConfig' also disables the logging of internal 'Event's.
+The 'defaultConfig' redirects all output to @\/dev\/null@. See
+'verboseConfig' for a version that logs more output.
 
 To append additional lines to \"postgresql.conf\" file create a
 custom 'Config' like the following.
@@ -160,7 +176,7 @@ custom 'Config' like the following.
 Or using the provided lenses and your favorite lens library:
 
  @
-  custom = defaultConfig & 'planL' . 'postgresConfigFile' <>~
+  custom = defaultConfig & 'planL' . 'postgresConfigFileL' <>~
     [ "wal_level = replica"
     , "archive_mode = on"
     , "max_wal_senders = 2"
@@ -175,14 +191,12 @@ Or using the provided lenses and your favorite lens library:
  As an alternative to using 'defaultConfig' one could create a
  config from connections parameters using 'optionsToDefaultConfig'.
 
-
-@since 1.12.0.0
+@since 1.21.0.0
 -}
 defaultConfig :: Config
 defaultConfig = mempty
   { plan = mempty
-    { logger = pure mempty
-    , postgresConfigFile = defaultPostgresConfig
+    { postgresConfigFile = fastPostgresConfig
     , initDbConfig = pure mempty
       { commandLine = mempty
         { keyBased = Map.singleton "--no-sync" Nothing
@@ -191,6 +205,27 @@ defaultConfig = mempty
     }
   }
 
+{-|
+Default configuration for PostgreSQL versions 9.3 and greater but less
+than 10.
+
+If you get an error that \"--no-sync\" is an invalid parameter then you
+should use this config.
+
+@since 1.21.1.0
+-}
+defaultConfig_9_3_10 :: Config
+defaultConfig_9_3_10 = mempty
+  { plan = mempty
+    { postgresConfigFile = fastPostgresConfig
+    , initDbConfig = pure mempty
+      { commandLine = mempty
+        { keyBased = Map.singleton "--nosync" Nothing
+        }
+      }
+    }
+  }
+
 {-|
 'mappend' the 'defaultConfig' with a 'Config' that provides additional
    \"postgresql.conf\" lines. Equivalent to:
@@ -206,10 +241,10 @@ defaultConfig = mempty
 or with lenses:
 
 @
-'defaultPostgresConf' extra = 'defaultConfig' & 'planL' . 'postgresConfigFile' <>~ extra
+'defaultPostgresConf' extra = 'defaultConfig' & 'planL' . 'postgresConfigFileL' <>~ extra
 @
 
-@since 1.12.0.0
+@since 1.21.0.0
 -}
 defaultPostgresConf :: [String] -> Config
 defaultPostgresConf extra = defaultConfig <> mempty
@@ -218,50 +253,34 @@ defaultPostgresConf extra = defaultConfig <> mempty
     }
   }
 
-
-{-|
-A config that logs as little as possible.
-
-@since 1.14.0.0
--}
-silentPostgresConfig :: [String]
-silentPostgresConfig =
+-- | Default postgres options
+--
+--   @since 1.21.0.0
+verbosePostgresConfig :: [String]
+verbosePostgresConfig =
   [ "shared_buffers = 12MB"
   , "fsync = off"
   , "synchronous_commit = off"
   , "full_page_writes = off"
-  , "log_min_messages = PANIC"
-  , "log_min_error_statement = PANIC"
-  , "log_statement = none"
-  , "client_min_messages = ERROR"
+  , "log_min_duration_statement = 0"
+  , "log_connections = on"
+  , "log_disconnections = on"
+  , "client_min_messages = WARNING"
   ]
 
 {-|
-The similar to 'defaultConfig' but all the handles are set to @\/dev\/null@.
-and uses a @postgresql.conf@ which disables logging:
+The similar to 'defaultConfig' log as much as possible.
 
- @
-   shared_buffers = 12MB
-   fsync = off
-   synchronous_commit = off
-   full_page_writes = off
-   log_min_messages = PANIC
-   log_min_error_statement = PANIC
-   log_statement = none
-   client_min_messages = ERROR
- @
-
-See 'silentProcessConfig' as well.
-
-@since 1.14.0.0
+@since 1.21.0.0
 -}
-silentConfig :: Config
-silentConfig = defaultConfig <> mempty
+verboseConfig :: Config
+verboseConfig = defaultConfig <> mempty
   { plan = mempty
-    { postgresConfigFile = silentPostgresConfig
-    , initDbConfig = pure silentProcessConfig
+    { logger = pure print
+    , postgresConfigFile = verbosePostgresConfig
+    , initDbConfig = pure standardProcessConfig
     , postgresPlan = mempty
-        { postgresConfig = silentProcessConfig
+        { postgresConfig = standardProcessConfig
         }
     }
   }
@@ -321,7 +340,7 @@ startConfig extra = try $ evalContT $ do
 -- | Default start behavior. Equivalent to calling 'startConfig' with the
 --   'defaultConfig'.
 --
---   @since 1.12.0.0
+--   @since 1.21.0.0
 start :: IO (Either StartError DB)
 start = startConfig defaultConfig
 
@@ -378,7 +397,7 @@ reloadConfig db =
 Exception safe database create with options. See 'startConfig' for more
 details. Calls 'stop' even in the face of exceptions.
 
-@since 1.15.0.0
+@since 1.21.0.0
 -}
 withConfig :: Config
          -- ^ @extra@. 'Config' combined with the generated 'Config'. See
@@ -395,7 +414,7 @@ withConfig extra f = bracket (startConfig extra) (either mempty stop) $
    'with' = 'withConfig' 'defaultConfig'
  @
 
-@since 1.15.0.0
+@since 1.21.0.0
 -}
 with :: (DB -> IO a)
      -- ^ @action@ continuation.
@@ -413,19 +432,9 @@ withRestart db f = bracket (restart db) (either mempty stop) $
 --   want to create a database owned by a specific user you will also login
 --   with among other use cases.
 --
---   @since 1.15.0.0
+--   @since 1.21.0.0
 optionsToDefaultConfig :: Client.Options -> Config
-optionsToDefaultConfig opts@Client.Options {..} =
-  let generated = optionsToConfig opts
-      startingConfig =
-        if createDbConfig (plan generated) == mempty
-          then defaultConfig
-          else defaultConfig <> mempty
-            { plan = mempty
-              { createDbConfig = pure standardProcessConfig
-              }
-            }
-  in startingConfig <> generated
+optionsToDefaultConfig opts = defaultConfig <> optionsToConfig opts
 
 -------------------------------------------------------------------------------
 -- Pretty Printing
@@ -442,7 +451,7 @@ prettyPrintDB = show . pretty
 {-|
 Configuration for the @initdb@ data directory cache.
 
-@since 1.15.1.0
+@since 1.20.0.0
 -}
 data CacheConfig = CacheConfig
   { cacheTemporaryDirectory :: FilePath
@@ -450,15 +459,28 @@ data CacheConfig = CacheConfig
   -- 'Temporary'. @\/tmp@ is a good default.
   , cacheDirectoryType      :: DirectoryType
   -- ^ Used to specify is a 'Permanent' or 'Temporary' directory should be
-  --   used. 'createDefaultCacheConfig' uses 'Permanent' @~\/.tmp-postgres@
+  --   used. 'defaultCacheConfig' uses 'Permanent' @~\/.tmp-postgres@
   --   by default.
   , cacheUseCopyOnWrite     :: Bool
   -- ^ Some operatoring system versions support flags for @cp@ that allow
-  --   \"copy on write\" which is about 2x faster. 'createDefaultCacheConfig'
+  --   \"copy on write\" which is about 2x faster. 'defaultCacheConfig'
   --   attempts to determine if the @cp@ on the path supports copy on write
   --   and sets this to 'True' if it does.
   }
 
+{-|
+A handle to cache temporary resources and configuration.
+
+@since 1.20.0.0
+-}
+data CacheResources = CacheResources
+  { cacheResourcesCow :: Bool
+  , cacheResourcesDirectory :: CompleteDirectoryType
+  } deriving stock (Generic)
+    deriving anyclass (NFData)
+
+-- | A bool that is 'True' if the @cp@ on the path supports \"copy on write\"
+--   flags.
 cowCheck :: Bool
 cowCheck = unsafePerformIO $ do
   let
@@ -493,11 +515,10 @@ defaultCacheConfig = CacheConfig
   , cacheUseCopyOnWrite = cowCheck
   }
 
-
 -- | Setup the @initdb@ cache folder.
 setupInitDbCache
   :: CacheConfig
-  -> IO (Bool, CompleteDirectoryType)
+  -> IO CacheResources
 setupInitDbCache CacheConfig {..} =
   bracketOnError
     (setupDirectoryType
@@ -505,15 +526,15 @@ setupInitDbCache CacheConfig {..} =
       "tmp-postgres-cache"
       cacheDirectoryType
     )
-    cleanupDirectoryType $ pure . (cacheUseCopyOnWrite,)
+    cleanupDirectoryType $ pure . CacheResources cacheUseCopyOnWrite
 
 {-|
 Cleanup the cache directory if it was 'Temporary'.
 
-@since 1.15.1.0
+@since 1.20.0.0
 -}
-cleanupInitDbCache :: (Bool, CompleteDirectoryType) -> IO ()
-cleanupInitDbCache = cleanupDirectoryType . snd
+cleanupInitDbCache :: CacheResources -> IO ()
+cleanupInitDbCache = cleanupDirectoryType . cacheResourcesDirectory
 
 {-|
 Enable @initdb@ data directory caching. This can lead to a 4x speedup.
@@ -524,12 +545,12 @@ Exception safe version of 'setupInitDbCache'. Equivalent to
    'withDbCacheConfig' = bracket ('setupInitDbCache' config) 'cleanupInitDbCache'
 @
 
-@since 1.15.1.0
+@since 1.20.0.0
 -}
 withDbCacheConfig
   :: CacheConfig
   -- ^ Configuration
-  -> ((Bool, CompleteDirectoryType) -> IO a)
+  -> (CacheResources -> IO a)
   -- ^ action for which caching is enabled
   -> IO a
 withDbCacheConfig config =
@@ -539,35 +560,45 @@ withDbCacheConfig config =
 Equivalent to 'withDbCacheConfig' with the 'CacheConfig'
 'defaultCacheConfig' makes.
 
-@since 1.15.1.0
+@since 1.20.0.0
 -}
-withDbCache :: ((Bool, CompleteDirectoryType) -> IO a) -> IO a
+withDbCache :: (CacheResources -> IO a) -> IO a
 withDbCache = withDbCacheConfig defaultCacheConfig
 
 {-|
 Helper to make a 'Config' out of caching info.
 
-@since 1.15.1.0
+@since 1.22.0.0
 -}
-toCacheConfig :: (Bool, CompleteDirectoryType) -> Config
-toCacheConfig cacheInfo = mempty
-  { initDbCache = pure $ pure $ fmap toFilePath cacheInfo
+cacheResourcesToConfig :: CacheResources -> Config
+cacheResourcesToConfig CacheResources {..} = mempty
+  { initDbCache = pure $ pure
+      (cacheResourcesCow, toFilePath cacheResourcesDirectory)
   }
 
 -------------------------------------------------------------------------------
 -- withSnapshot
 -------------------------------------------------------------------------------
+{-|
+A type to track a possibly temporary snapshot directory
+
+@since 1.20.0.0
+-}
+newtype Snapshot = Snapshot { unSnapshot :: CompleteDirectoryType }
+  deriving stock (Generic)
+  deriving anyclass (NFData)
+
 {- |
 Shutdown the database and copy the directory to a folder.
 
-@since 1.17.0.0
+@since 1.20.0.0
 -}
 takeSnapshot
   :: DirectoryType
   -- ^ Either a 'Temporary' or preexisting 'Permanent' directory.
   -> DB
   -- ^ The handle. The @postgres@ is shutdown and the data directory is copied.
-  -> IO (Either StartError CompleteDirectoryType)
+  -> IO (Either StartError Snapshot)
 takeSnapshot directoryType db = try $ do
   throwIfNotSuccess id =<< stopPostgresGracefully db
   let
@@ -588,15 +619,15 @@ takeSnapshot directoryType db = try $ do
       throwIfNotSuccess (SnapshotCopyFailed snapshotCopyCmd) =<<
         system snapshotCopyCmd
 
-      pure snapShotDir
+      pure $ Snapshot snapShotDir
 
 {-|
 Cleanup any temporary resources used for the snapshot.
 
-@since 1.17.0.0
+@since 1.20.0.0
 -}
-cleanupSnapshot :: CompleteDirectoryType -> IO ()
-cleanupSnapshot = cleanupDirectoryType
+cleanupSnapshot :: Snapshot -> IO ()
+cleanupSnapshot = cleanupDirectoryType . unSnapshot
 
 {- |
 Exception safe method for taking a file system level copy of the database cluster.
@@ -604,12 +635,12 @@ Exception safe method for taking a file system level copy of the database cluste
 Snapshots are useful if you would like to start every test from a migrated database
 and the migration process is more time consuming then copying the additional data.
 
-@since 1.17.0.0
+@since 1.20.0.0
 -}
 withSnapshot
   :: DirectoryType
   -> DB
-  -> (CompleteDirectoryType -> IO a)
+  -> (Snapshot -> IO a)
   -> IO (Either StartError a)
 withSnapshot dirType db f = bracket
   (takeSnapshot dirType db)
@@ -620,17 +651,16 @@ withSnapshot dirType db f = bracket
 Convert a snapshot into a 'Config' that includes a 'copyConfig' for copying the
 snapshot directory to a temporary directory.
 
-@since 1.17.0.0
+@since 1.20.0.0
 -}
-configFromSavePoint :: FilePath -> IO Config
-configFromSavePoint savePointPath = do
-  pure mempty
-    { plan = mempty
-        { copyConfig = pure $ pure CopyDirectoryCommand
-            { sourceDirectory = savePointPath
-            , destinationDirectory = Nothing
-            , useCopyOnWrite = cowCheck
-            }
-        , initDbConfig = Zlich
-        }
-    }
+snapshotConfig :: Snapshot -> Config
+snapshotConfig (Snapshot savePointPath) = mempty
+  { plan = mempty
+      { copyConfig = pure $ pure CopyDirectoryCommand
+          { sourceDirectory = toFilePath savePointPath
+          , destinationDirectory = Nothing
+          , useCopyOnWrite = cowCheck
+          }
+      , initDbConfig = Zlich
+      }
+  }
